function equationFit(x, y, curve_type, p, attempt_max)

%Checking for user-defined number of maximum attempts
if nargin <= 4
    attempt_max = 5;
    
end

%Initialising parameters (if needed)
if strcmpi(curve_type, 'sigmoidal')
    if nargin <= 3
        p(1) = max(y); p(2) = 0.1; p(3) = max(x)/2;
        
    end
    
end

%First attempt
attempts = 1;
[new_p, fval, exitflag] = fminsearch(@(p) efCalcResidual(x, y, curve_type, p), p);

%Subsequent attempts (if needed)
while attempts < attempt_max
    if exitflag == 0
        [new_p, fval, exitflag] = fminsearch(@(new_p) efCalcResidual(x, y, curve_type, new_p), new_p);
         
    end
    
    attempts = attempts +1;
    
end

%Displaying output
if strcmpi(curve_type, 'sigmoidal')
    disp('y = a/(1 + exp(-k*(x-xc)))');
    disp(strcat(['a = ', num2str(new_p(1)), ', k = ', num2str(new_p(2)), ', xc = ', num2str(new_p(3))]));
    new_y = new_p(1)./(1 + exp(-new_p(2)*(x-new_p(3))));
    
end

close(gcf)
figure
hold on

plot(x,y,'r');
plot(x, new_y, 'bo')

disp(' ')
