function imageSplitter(f_name)

%% Setting some parameters
%If one channel is particularly dark it can be amplified using "left_gain"
%for the left image or "right_gain" for the right image.  This applies a
%linear multiplication factor to all pixel intensities.  However, it is 
%possible to clip intensities if they exceed the 0-255 intensity range.
left_gain = 1;
right_gain = 1;

%% Loading the input and output video files and the configuration file
%The input video file
video_read_obj = VideoReader(strcat([f_name, '.avi']));

%The output video file
video_write_obj = VideoWriter(strcat([f_name, '_superimposed_video.avi']...
    ), 'Uncompressed AVI');
open(video_write_obj);

%The configuration file in the current working directory
load('ImageSplitterSettings');

%% Assigning the two image regions to a single video
%The border is applied to both images, so the combined image contains both
%channels
border = max(abs([hor_corr, ver_corr]));

%For each frame in the video, the left and right images are extracted and
%assigned to the red and green channels (respectively) of the output video 
%current frame.
for i = 1:video_read_obj.NumberOfFrames
[left_im, right_im] = isTrimImages(read(video_read_obj,i), left_pos, ...
    right_pos);

cropped_right_im = right_im(border+1:size(right_im,1)-border,border+1:...
    size(right_im,2)-border);
cropped_left_im = left_im(border+1+ver_corr:size(left_im,1)-border+...
    ver_corr,border+1+hor_corr:size(left_im,2)-border+hor_corr);

%Combining the left and right images onto the current frame image
combined_im(:,:,1) = cropped_left_im;
combined_im(:,:,1:3) = 0;

if strcmpi(left_colour, 'Red')
    combined_im(:,:,1) = cropped_left_im*left_gain;
elseif strcmpi(left_colour, 'Green')
    combined_im(:,:,2) = cropped_left_im*left_gain;
elseif strcmpi(left_colour, 'Blue')
    combined_im(:,:,3) = cropped_left_im*left_gain;
end

if strcmpi(right_colour, 'Red')
    combined_im(:,:,1) = cropped_right_im*right_gain;
elseif strcmpi(right_colour, 'Green')
    combined_im(:,:,2) = cropped_right_im*right_gain;
elseif strcmpi(right_colour, 'Blue')
    combined_im(:,:,3) = cropped_right_im*right_gain;
end

%Displaying the current frame image
imshow(combined_im)

%Writing the current frame to the output video file
writeVideo(video_write_obj, getframe(gcf));

end

%Closing the current output video image and file
close(gcf);
close(video_write_obj);