function isAlignImages(f_name, cali_im, left_pos, left_colour, right_pos, right_colour)

%% Setting some variables
border = 20; %The range over which one image is moved relative to the other
screen_dimensions = get(0, 'ScreenSize');

initial_border = border; %For use later when displaying the images

%Creating two separate images, "left_im" and "right_im" from the
%coordinates specified of the calibration image
[left_im, right_im] = isTrimImages(cali_im, left_pos, right_pos);

%% Moving the left image across the right image and measuring difference
% The right image stays in the same place.  The image to be moved is
% cropped with an equal width border around the edge, the same width as
%"border", so no negative pixels are accessed
cropped_right_im = right_im(border+1:size(right_im,1)-border,border+1:...
    size(right_im,2)-border);

% Moving the left image across within the borders
ver_corr = -border;
hor_corr = -border;

%Initialising the table to contain the residual values at each alignment
%position
residual_table(1:2*border, 1:2*border, 1:3) = 0;

%Rastering one image across the other, the mean residual between the two
%images is calculated
for i = 1:2*border
    for j = 1:2*border
        %Cropping the other image to the same region as the right image
        %currently occupies
        cropped_left_im = left_im(border+1+ver_corr:size(left_im,1)-...
            border+ver_corr,border+1+hor_corr:size(left_im,2)-border+...
            hor_corr);
        
        %Subtracting one image from the other and saving the mean residual
        %along with the current image offset to "residual_table"
        sub_im = double(cropped_right_im) - double(cropped_left_im);
        residual_table(i,j,1) = ver_corr;
        residual_table(i,j,2) = hor_corr;
        residual_table(i,j,3) = mean(mean(abs(sub_im)));
        
        clear cropped_left_im
        
        hor_corr = hor_corr + 1;
        
    end
    
    ver_corr = ver_corr + 1;
    hor_corr = -border;
    
end


%% Getting the vertical and horizontal corrections from the measured data
%Obtaining the horizontal and vertical offset values based on the smallest
%residual
[x, y] = find(residual_table(:,:,3) == min(min(residual_table(:,:,3))));
ver_corr = residual_table(x,y,1);
hor_corr = residual_table(x,y,2);

disp(strcat(['Vertical correction: ', num2str(ver_corr)]))
disp(strcat(['Horizontal correction: ', num2str(hor_corr)]))


%% Plotting the alignment
%Setting the border to the minimum necessary
border = max(abs([hor_corr, ver_corr]));

%Creating the final images cropped to the same region
cropped_right_im = right_im(border+1:size(right_im,1)-border,border+1:...
    size(right_im,2)-border);
cropped_left_im = left_im(border+1+ver_corr:size(left_im,1)-border+...
    ver_corr,border+1+hor_corr:size(left_im,2)-border+hor_corr);

%Scaling "residual_table", so it fills the full colormap range (0-60)
residual_table(:,:,3) = residual_table(:,:,3)-...
    min(min(residual_table(:,:,3)));
residual_table(:,:,3) = residual_table(:,:,3)*...
    (60/max(max(residual_table(:,:,3))));

%Displaying the residual between the two images
figure
subplot(1,2,1)
image(residual_table(:,:,3))
daspect([1 1 1])
set(gca, 'XTick', 1:5:2*initial_border+1, 'XTickLabel', -initial_border:...
    5:initial_border);
set(gca, 'YTick', 1:5:2*initial_border+1, 'YTickLabel', -initial_border:...
    5:initial_border);
xlabel('X-position offset (pixels)');
ylabel('Y-position offset (pixels)');

%Creating a superimposed image with the left image in the red channel and
%the right image in the green channel
sub_im = uint8(cropped_left_im);

sub_im(:,:,1:3) = 0;

if strcmpi(left_colour, 'Red')
    sub_im(:,:,1) = sub_im(:,:,1)+uint8(cropped_left_im);
elseif strcmpi(left_colour, 'Green')
    sub_im(:,:,2) = sub_im(:,:,2)+uint8(cropped_left_im);
elseif strcmpi(left_colour, 'Blue')
    sub_im(:,:,3) = sub_im(:,:,3)+uint8(cropped_left_im);
end

if strcmpi(right_colour, 'Red')
    sub_im(:,:,1) = sub_im(:,:,1)+uint8(cropped_right_im);
elseif strcmpi(right_colour, 'Green')
    sub_im(:,:,2) = sub_im(:,:,2)+uint8(cropped_right_im);
elseif strcmpi(right_colour, 'Blue')
    sub_im(:,:,3) = sub_im(:,:,3)+uint8(cropped_right_im);
end

set(gcf, 'Position', screen_dimensions+[50 50 -100 -150]);
subplot(1,2,2)
imshow(sub_im);

%Saving the superimposed image and calibration settings
imwrite(frame2im(getframe(gcf)), strcat([f_name, ...
    '_calibration_superimposed.png']));
save('imageSplitterSettings', 'left_pos', 'right_pos', 'ver_corr', ...
    'hor_corr', 'left_colour', 'right_colour');

disp([' '])

