function isCalibrateImageSplitter(f_name, ext)

%% Loading the calibration image specified by the given filename
cali_im = imread(strcat([f_name, '.', ext]));

%% Displaying the calibration image and setting it full screen
screen_dimensions = get(0, 'ScreenSize');
curr_fig = figure();
imshow(cali_im);
set(curr_fig, 'Position', screen_dimensions+[50 50 -100 -150]);

%% Initialising some variables
roi_left = 1;
roi_right = 1;
set_roi_left_cnd = 0;
set_roi_right_cnd = 0;
left_pos = 0;
right_pos = 0;
left_colour = [];
right_colour = [];

%% Creating UI elements on the calibration image
%A button to the right of the calibration image called "Set left ROI".
%When pressed, the user will be able to specify the left ROI, which is
%stored in the "left_pos" variable and sets "set_roi_left_cnd" to "1".
uicontrol('Style', 'pushbutton', 'String', 'Set left ROI', 'Units', ...
    'Normalized', 'Position', [0.927 0.27 0.05 0.04], 'Callback', ...
    @selectLeftROI);
    function selectLeftROI(~, ~)
        roi_left = imrect';
        left_pos = getPosition(roi_left);
        set_roi_left_cnd = 1;
        
        left_colour = questdlg('Select colour for channel', ...
            'Left ROI colour', 'Red', 'Green', 'Blue', 'Red');
    end

%A button to the right of the calibration image called "Set right ROI".
%When pressed, the user will be able to specify the right ROI, which is
%stored in the "right_pos" variable and sets "set_roi_right_cnd" to "1".
uicontrol('Style', 'pushbutton', 'String', 'Set right ROI', 'Units', ...
    'Normalized', 'Position', [0.927 0.22 0.05 0.04], 'Callback', ...
    @selectRightROI);
    function selectRightROI(~, ~)
        roi_right = imrect';
        right_pos = getPosition(roi_right);
        set_roi_right_cnd = 1;
        
        right_colour = questdlg('Select colour for channel', ...
            'Right ROI colour', 'Red', 'Green', 'Blue', 'Red');
    end

%Once the user has specified both left and right image ROIs the button 
%"Try alignment" can be pressed.  This checks if both ROIs have been
%specified; if they have, the function "alignImages.m" executes
uicontrol('Style', 'pushbutton', 'String', 'Try alignment', 'Units', ...
    'Normalized', 'Position', [0.927 0.12 0.05 0.04], 'Callback', ...
    @tryAlign);
    function tryAlign(~, ~)
        if set_roi_left_cnd == 1 && set_roi_right_cnd == 1;
            close(curr_fig);
            isAlignImages(f_name, cali_im, left_pos, left_colour, ...
                right_pos, right_colour);
        else
            warndlg('Set both ROIs before selecting "Try overlay"');
            
        end
    end

end
