function [left_im, right_im] = isTrimImages(cali_im, left_pos, right_pos)

%% Acquiring the individual images based on the ROIs
left_im = cali_im(ceil(left_pos(2)):ceil(left_pos(2)+left_pos(4)),...
    ceil(left_pos(1)):ceil(left_pos(1)+left_pos(3)));
right_im = cali_im(ceil(right_pos(2)):ceil(right_pos(2)+right_pos(4)),...
    ceil(right_pos(1)):ceil(right_pos(1)+right_pos(3)));


%% Giving the images equal widths and heights
%The left and right images are trimmed, so they are the same size.  The
%largest possible size in both directions is taken, so the least
%information is trimmed.

%Each image is tested to see if it has the largest width.  If this is the
%case, it is trimmed to the width of the other image.
min_width = min(size(left_im,2), size(right_im,2));
if min_width ~= size(left_im,2)
    left_im(:,ceil(size(left_im,2)-(size(left_im,2)-min_width)/2):...
        size(left_im,2)) = [];
    left_im(:,1:size(left_im,2)-min_width) = [];
    
elseif min_width ~= size(right_im,2)
    right_im(:,ceil(size(right_im,2)-(size(right_im,2)-min_width)/2):...
        size(right_im,2)) = [];
    right_im(:,1:size(right_im,2)-min_width) = [];
    
end

%Each image is tested to see if it has the largest height.  If this is the
%case, it is trimmed to the height of the other image.
min_height = min(size(left_im,1), size(right_im,1));
if min_height ~= size(left_im,1)
    left_im(ceil(size(left_im,1)-(size(left_im,1)-min_height)/2):...
        size(left_im,1),:) = [];
    left_im(1:size(left_im,1)-min_height,:) = [];
    
elseif min_height ~= size(right_im,1)
    right_im(ceil(size(right_im,1)-(size(right_im,1)-min_height)/2):...
        size(right_im,1),:) = [];
    right_im(1:size(right_im,1)-min_height,:) = [];
    
end

%The trimmed images are returned by the function
