function measurePhotocleavage(root_f_name)
%% Setting some parameters
exact_names = 0; %"1" will require the exact filename, apart from number,
%"0" finds all names that start with the given name
width = 4; %Width of the DNA-identifier line
av_num_width = 1;

%% Initialising some variables
pos_table(1,1:4) = 0;
n_pos = 0;

%% Loading the images starting with the supplied root filename
f_list = dir;
im_stack_i = 1;
for i = 1:length(f_list)
    f_name = f_list(i).name;
    
    if length(f_name) > length(root_f_name)
        if strcmpi(f_name(1:length(root_f_name)), root_f_name)
            im_stack(:,:,im_stack_i) = rgb2gray(imread(f_list(i).name));
            im_stack_i = im_stack_i + 1;
        end
    end
end

%% Displaying the first image in the stack
curr_fig = figure();
imshow(im_stack(:,:,1));
screen_dimensions = get(0, 'ScreenSize');
set(curr_fig, 'Position', screen_dimensions);

%Adding a button to say when all DNA molecules have been identified
uicontrol('Style', 'pushbutton', 'String', 'Measure', 'Units', ...
    'Normalized', 'Position', [0.927 0.12 0.05 0.04], 'Callback', ...
    @tryOverlay);

    function tryOverlay(~, ~)
        select_lines_cnd = 1;
        close(curr_fig)
    end

%% Acquiring DNA locations based on lines drawn on the image by the user
select_lines_cnd = 0;
while select_lines_cnd == 0
    %Once "Measure" has been selected the code will want to do a final
    %selection, which has already been called.  When the figure is closed,
    %this incomplete function would cause the code to fail.  This "try"
    %statement prevents that.
    try
        roi_left = imline';
        left_pos = getPosition(roi_left);
        pos_table(n_pos+1,1) = left_pos(1,1); %x-pos min
        pos_table(n_pos+1,2) = left_pos(2,1); %x-pos max
        pos_table(n_pos+1,3) = left_pos(1,2); %y-pos min
        pos_table(n_pos+1,4) = left_pos(2,2); %y-pos max
        
        n_pos = n_pos + 1;
    end
end

%% Measuring pixel intensities along the identified lines for each image
for t = 1:size(im_stack,3)
    %The process is repeated for all identified DNA positions
    for pos = 1:n_pos
        %Calculating the horizontal end locations of each DNA and the angle
        %the line makes with the x-axis (horizontal)
        x_min = min(pos_table(pos,1:2));
        x_max = max(pos_table(pos,1:2));
        theta = atan((pos_table(pos,4)-pos_table(pos,3))/(x_max-x_min));
        
        %For each pixel location along the x-axis, the corresponding
        %y-location is calculated.  At each location the mean pixel
        %intensity in the area specified by "width" is measured and stored
        %in "temp_data"
        for i = 1:x_max-x_min
            temp_data(i) = mean(mean(im_stack(ceil((i-1)*tan(theta)+...
                pos_table(pos,3)-width/2):ceil((i-1)*tan(theta)+...
                pos_table(pos,3)+width/2), ceil(x_min+i-1-width):...
                ceil(x_min+i-1+width),t)));
        end
        
        %The mean intensity along the line is saved in "intensity_table" as
        %a function of frame ("t") and which DNA position is being
        %investigated
        intensity_table(t,pos) = mean(temp_data);
        
        clear x_min x_max theta temp_data
    end
    
    %Taking the average image intensity as a reference and storing the
    %value in "av_im_intensity" as a function of frame number ("t")
    av_im_intensity(t,1) = mean(mean(im_stack(:,:,t)));
end

for i = 1+av_num_width:size(im_stack,3)-av_num_width
    im_stack_AV(:,:,i-av_num_width) = double(im_stack(:,:,i-av_num_width));
    for j = i-av_num_width+1:i+av_num_width
        im_stack_AV(:,:,i-av_num_width) = im_stack_AV(:,:,i-av_num_width) + ...
            double(im_stack(:,:,j));
    end
    
    im_stack_AV(:,:,i-av_num_width) = im_stack_AV(:,:,i-av_num_width)./...
        (2*av_num_width+1);
end

im_stack_AV = uint8(im_stack_AV);

%% Measuring pixel intensities along the identified lines for each image
for t = 1:size(im_stack_AV,3)-2*av_num_width
    %The process is repeated for all identified DNA positions
    for pos = 1:n_pos
        %Calculating the horizontal end locations of each DNA and the angle
        %the line makes with the x-axis (horizontal)
        x_min = min(pos_table(pos,1:2));
        x_max = max(pos_table(pos,1:2));
        theta = atan((pos_table(pos,4)-pos_table(pos,3))/(x_max-x_min));
        
        %For each pixel location along the x-axis, the corresponding
        %y-location is calculated.  At each location the mean pixel
        %intensity in the area specified by "width" is measured and stored
        %in "temp_data"
        for i = 1:x_max-x_min
            temp_data(i) = mean(mean(im_stack(ceil((i-1)*tan(theta)+...
                pos_table(pos,3)-width/2):ceil((i-1)*tan(theta)+...
                pos_table(pos,3)+width/2), ceil(x_min+i-1-width):...
                ceil(x_min+i-1+width),t)));
        end
        
        %The mean intensity along the line is saved in "intensity_table" as
        %a function of frame ("t") and which DNA position is being
        %investigated
        intensity_table_AV(t,pos) = mean(temp_data);
        
        clear x_min x_max theta temp_data
    end
    
    %Taking the average image intensity as a reference and storing the
    %value in "av_im_intensity" as a function of frame number ("t")
    av_im_intensity_AV(t,1) = mean(mean(im_stack_AV(:,:,t)));
end

%% Writing an image showing identifier numbers for each selected molecule
figure()
ref_im = im_stack(:,:,1);
imshow(ref_im);
for i = 1:n_pos
    text(pos_table(i,1),pos_table(i,3), num2str(i), 'Color', [1 0 0 ],...
        'FontWeight' ,'bold');
end
print('-dtiff', '-r200', 'nums.jpg');
close(gcf)

intensity_table2 = intensity_table;

%% Analysing the data
for i = 1:n_pos
    %Measuring the photocleavage point as the location with the greatest
    %gradient.  Photobleaching removed through subtraction of the reference
    %image intensity
    intensity_table(:,i) = intensity_table(:,i) - av_im_intensity(:,1);
    grad_table(:,i) = gradient(intensity_table(:,i));
    min_vals = find(grad_table(:,i) == min(grad_table(:,i)));
    pos_table(i,5) = min_vals(1);
    
    %Measuring the photocleavage point as the location with the greatest
    %gradient.  Photobleaching removed through subtraction of the reference
    %image intensity
    intensity_table2(:,i) = intensity_table2(:,i)./av_im_intensity(:,1);
    grad_table2(:,i) = gradient(intensity_table2(:,i));
    min_vals2 = find(grad_table2(:,i) == min(grad_table2(:,i)));
    pos_table(i,6) = min_vals2(1);
    
    %Measuring the photocleavage point as the location with the greatest
    %gradient.  Photobleaching removed through subtraction of the reference
    %image intensity.  FOR AVERAGE IMAG
    intensity_table_AV(:,i) = intensity_table_AV(:,i) - ...
        av_im_intensity_AV(:,1);
    grad_table_AV(:,i) = gradient(intensity_table_AV(:,i));
    min_vals_AV = find(grad_table_AV(:,i) == min(grad_table_AV(:,i)));
    pos_table(i,7) = min_vals_AV(1);
    
    %Measuring the photocleavage point as the location with the greatest
    %difference between mean intensities before and after.  Photobleaching
    %removed through subtraction of the reference image intensity
    for j = 2:size(intensity_table,1)-1
        min_max(j-1,1) = mean(intensity_table(1:j-1,i));
        min_max(j-1,2) = mean(intensity_table(j+1:size(intensity_table,...
            1),i));
        min_max(j-1,3) = min_max(j-1,1)-min_max(j-1,2);
    end
    
    pos_table(i,8) = find(min_max(:,3) == max(min_max(:,3)))+1; % Min-max measured photocleavage
    pos_table(i,9) = min_max(pos_table(i,8),1); %Max
    pos_table(i,10) = min_max(pos_table(i,8),2); %Min
    
    clear min_max
end

%% Saving data to a single Excel spreadsheet
try
    xlswrite(strcat(['Output for_', root_f_name, '.xls']), pos_table, ...
        'Positions');
    xlswrite(strcat(['Output for_', root_f_name, '.xls']), ...
        av_im_intensity, 'Av im intensity');
    xlswrite(strcat(['Output for_', root_f_name, '.xls']), ...
        intensity_table, 'Intensity');
    xlswrite(strcat(['Output for_', root_f_name, '.xls']), ...
        av_im_intensity_AV, 'Av im intensity AV');
    xlswrite(strcat(['Output for_', root_f_name, '.xls']), ...
        intensity_table_AV, 'Intensity AV');
catch
    disp 'Unable to write to file.  Attempting to use "temp.xls"';
    
    xlswrite('temp.xls', pos_table, 'Positions');
    xlswrite('temp.xls', av_im_intensity, 'Av im intensity');
    xlswrite('temp.xls', intensity_table, 'Intensity');
    xlswrite('temp.xls', av_im_intensity_AV, 'Av im intensity AV');
    xlswrite('temp.xls', intensity_table_AV, 'Intensity AV');
end
end