%This function "wraps" the vector to the point of interest
%round the cylinder with capped ends.  The
%vector is passed between the furthest extremes of the
%capped ends until the point of interest is located on
%either a cylindrical or hemispherical section.

function [dx dy dz out_of_field_cnd] = mcdCellCurvature(dx, dy, L, R, field_depth, out_of_field_cnd)
point_found = 0; %Is set to "1" when the curved surface-transformed point has been located

if dy < 0 %If the point of interest is below the coordinate system origin on the front-centre of the cyinder its sign is negative
    dy_sign = -1;
else %If the point is above the origin, its sign is positive
    dy_sign = 1;
end

if dx < 0 %Similarly for the x-coordinate relative to the same origin
    dx_sign = -1;
else
    dx_sign = 1;
end

%The signs of the points need to be recorded, because from
%here-on the script deals with magnitude.  Signs are
%inverted every time the point passes back past the origin
dy = abs(dy);
dx = abs(dx);

while point_found == 0;
    if dy <= L/2 %If the magnitude of the vector is less than L/2, the point lies on a cylinder section and the "cylinder_cnd" is set to "1"
        cylinder_cnd = 1;
        point_found = 1;
        
    else %The next area to evaluate is the capped end, so half the cylinder length is removed from the vector
        dy = dy - (L/2);
        
        if dy < pi*R %This tests to see if the new vector length will terminate on the capped end, assuming the vector passes through the end of the cap
            cylinder_cnd = 0;
            point_found = 1;
            
        else %If the vector still doesn't fit on the dome the half circumference of the dome and half the cylinder length are subtracted.  This puts the vector origin at the opposite side of the cylinder to where it started, but facing in the opposite direction, so the signs for "x" and "y" are inverted
            dy = dy - pi*R - (L/2);
            dy_sign = dy_sign*-1;
            dx_sign = dx_sign*-1;
            
        end
    end
end

%If the vector was determined to end on the cylinder the following executes
if cylinder_cnd == 1
    [dx dy dz out_of_field_cnd] = mcdCPCConversion(R, dx, dy, field_depth, out_of_field_cnd);
    dx = dx*dx_sign; %This table has the curvature corrected coordinates in it
    dy = dy*dy_sign;
    
    %If the vector ended on one of the capped ends, the following executes
elseif cylinder_cnd == 0
    [dx dy dz out_of_field_cnd] = mcdHemisphereConversion(dx, dy, R, out_of_field_cnd, field_depth);
    dx = dx*dx_sign; %This table has the curvature corrected coordinates in it
    dy = (dy+L/2)*dy_sign;
    
end