function [membrane_table] = mcdPopulateMembrane(range_x, range_y, percentage_total_occupancy, R_OmpF, R_OmpA, R_BtuB, rel_n_OmpF_trimer, rel_n_OmpA, rel_n_BtuB)

%% Initialising some variables
membrane_table = [];

%% Calculating number of each type required
total_occupied_area = percentage_total_occupancy*range_x*range_y;
OmpA_area = pi*(R_OmpA^2);
OmpF_trimer_area = (3*pi+sqrt(3)-pi/3)*(R_OmpF^2);
BtuB_area = pi*(R_BtuB)^2;
fraction_BtuB = rel_n_BtuB/(rel_n_BtuB+rel_n_OmpF_trimer+rel_n_OmpA);
fraction_OmpF_trimer = rel_n_OmpF_trimer/(rel_n_BtuB+rel_n_OmpF_trimer+rel_n_OmpA);
fraction_OmpA = rel_n_OmpA/(rel_n_BtuB+rel_n_OmpF_trimer+rel_n_OmpA);
OmpA_boundary = (R_OmpA + 2*R_OmpF + R_OmpF/tan(30*pi/180) - R_OmpF- R_OmpF*tan(30*pi/180));
OmpF_boundary = 2*(2*R_OmpF + R_OmpF/tan(30*pi/180) - R_OmpF- R_OmpF*tan(30*pi/180));
BtuB_boundary = (R_BtuB + 2*R_OmpF + R_OmpF/tan(30*pi/180) - R_OmpF- R_OmpF*tan(30*pi/180));

relative_number = (total_occupied_area)/(fraction_BtuB*BtuB_area+fraction_OmpF_trimer*OmpF_trimer_area+fraction_OmpA*OmpA_area);

BtuB_number = ceil(relative_number*fraction_BtuB);
OmpF_trimer_number = ceil(relative_number*fraction_OmpF_trimer);
OmpA_number = ceil(relative_number*fraction_OmpA);

disp_str = strcat('Number of accepted proteins: ', num2str(0), ' (', num2str(100*0/(range_x*range_y)), '%% occupancy)');
fprintf(1, strcat('\n',disp_str));

%% Running the simulation, first doing OmpF trimers as these are the largest objects
accepted_i = 1 ;

while size(membrane_table,1) < OmpF_trimer_number
    clear test_membrane_table
    accepted_cnd = 1;
    
    x = range_x*(rand(1,1)-0.5);
    y = range_y*(rand(1,1)-0.5);
    theta = rand*360;
    
    %% Testing the new position against existing positions
    if size(membrane_table,1) >= 1
        membrane_table_local = mcdCreateLocalTable(membrane_table, x, y, OmpF_boundary, 0);
        [accepted_cnd] = mcdComparePositions(membrane_table_local, x, y, theta, 1, R_OmpF, R_OmpA, R_BtuB, range_x, range_y);
        clear membrane_table_local
    end
    
    %% Registering the newly accepted position
    if accepted_cnd == 1
        membrane_table(size(membrane_table,1)+1,1) = x;
        membrane_table(size(membrane_table,1),2) = y;
        membrane_table(size(membrane_table,1),3) = theta;
        membrane_table(size(membrane_table,1),4) = 1; % "1" means it is an OmpF trimer
        
        new_disp_str = strcat('Number of accepted proteins: ', num2str(size(membrane_table,1)), ' (', num2str(100*size(membrane_table,1)*OmpF_trimer_area/(range_x*range_y)), '% occupancy)');
        fprintf(1, strcat(repmat('\b',1,size(disp_str,2)),'%s'), new_disp_str)
        disp_str = new_disp_str;
        
        accepted_i = accepted_i + 1;
    end
end


%% Second positioning the BtuB as these are second largest
while size(membrane_table,1) < OmpF_trimer_number + BtuB_number
    clear test_membrane_table
    accepted_cnd = 1;
    
    x = range_x*(rand(1,1)-0.5);
    y = range_y*(rand(1,1)-0.5);
    theta = rand*360;
    
    %% Testing the new position against existing positions
    if size(membrane_table,1) >= 1
        membrane_table_local = mcdCreateLocalTable(membrane_table, x, y, BtuB_boundary, 0);
        [accepted_cnd] = mcdComparePositions(membrane_table_local, x, y, theta, 3, R_OmpF, R_OmpA, R_BtuB, range_x, range_y);
        clear membrane_table_local
    end
    
    %% Registering the newly accepted position
    if accepted_cnd == 1
        membrane_table(size(membrane_table,1)+1,1) = x;
        membrane_table(size(membrane_table,1),2) = y;
        membrane_table(size(membrane_table,1),3) = theta;
        membrane_table(size(membrane_table,1),4) = 3; % "3" means it is a BtuB
        
        new_disp_str = strcat('Number of accepted proteins: ', num2str(size(membrane_table,1)), ' (', num2str(100*(OmpF_trimer_number*OmpF_trimer_area+(size(membrane_table,1)-OmpF_trimer_number)*BtuB_area)/(range_x*range_y)), '% occupancy)');
        fprintf(1, strcat(repmat('\b',1,size(disp_str,2)),'%s'), new_disp_str)
        disp_str = new_disp_str;
        accepted_i = accepted_i + 1;
    end
end


%% Third, positioning the OmpA monomers as these are the smallest
while size(membrane_table,1) < OmpF_trimer_number + BtuB_number + OmpA_number
    clear test_membrane_table
    accepted_cnd = 1;
    
    x = range_x*(rand(1,1)-0.5);
    y = range_y*(rand(1,1)-0.5);
    theta = rand*360;
    
    %% Testing the new position against existing positions
    if size(membrane_table,1) >= 1
        membrane_table_local = mcdCreateLocalTable(membrane_table, x, y, OmpA_boundary, 0);
        [accepted_cnd] = mcdComparePositions(membrane_table_local, x, y, theta, 2, R_OmpF, R_OmpA, R_BtuB, range_x, range_y);
        clear membrane_table_local
    end
    
    %% Registering the newly accepted position
    if accepted_cnd == 1
        membrane_table(size(membrane_table,1)+1,1) = x;
        membrane_table(size(membrane_table,1),2) = y;
        membrane_table(size(membrane_table,1),3) = theta;
        membrane_table(size(membrane_table,1),4) = 2; % "2" means it is an OmpF monomer
        
        new_disp_str = strcat('Number of accepted proteins: ', num2str(size(membrane_table,1)), ' (', num2str(100*(OmpF_trimer_number*OmpF_trimer_area+BtuB_number*BtuB_area+(size(membrane_table,1)-OmpF_trimer_number-BtuB_number)*OmpA_area)/(range_x*range_y)), '% occupancy)');
        fprintf(1, strcat(repmat('\b',1,size(disp_str,2)),'%s'), new_disp_str)
        disp_str = new_disp_str;
        accepted_i = accepted_i + 1;
    end
end