%This script compares the current and previous mesh square coordinates to
%see if they are the same.  If they are the same, the particle can diffuse
%freely.  If they are different, the probability of the particle passing
%through the boundary is determined by a simple random number/threshold
%approach.

function [dx dy previous_box] = mcdRestrictedMovement(dx, dy, dx_previous, dy_previous, mesh_x_origin, mesh_y_origin, previous_box, box_size, boundary_pass_threshold)

dx = dx + mesh_x_origin;    %When locating the mesh square, any induced "wobble" in the mesh is removed temporarily
dy = dy + mesh_y_origin;
[current_box] = mcdMeshFind(dx, dy, box_size); %Locating the coordinate of the current mesh square in which the particle resides
dx = dx - mesh_x_origin;    %Replacing the positions around the origin
dy = dy - mesh_y_origin;

if current_box(1,1) ~= previous_box(1,1) || current_box(1,2) ~= previous_box(1,2)  %In this situation the particle has tried to go through a boundary in the mesh
    if rand > boundary_pass_threshold %The particle can pass through the boundary
        previous_box = current_box; %This is now saved for the next iteration
    else    %The particle can't move through the boundary
        dx = dx_previous;
        dy = dy_previous;
    end
end