function mcdSettings

%% Setting parameters
%File settings
filename_return = inputdlg('Enter filename for output');
filename = filename_return{1};

%Diffusion parameters
D = 0.03e-012; %Diffusion coefficient
n = 5000;  %Number of particles to evaluate
total_time_s = 0.85;  %Total time (s)
dt_s = 1E-6;   %Time step (s)

%TIRFM parameters
field_depth = 150E-9; %Depth of the evanescent field from the surface
intensity0 = 1; %Maximum evanescent field intensity
lambda0 = 488E-9; %Incident laser wavelength
tirfm_angle = 76*pi/180; %Angle of laser incidence
n1 = 1.46355; %Refractive index 1
n2 = 1.333;  %Refractive index 2
d = (lambda0/(4*pi))*sqrt(((n1^2)*((sin(tirfm_angle))^2))-(n2^2));   %Decay constant for the evanescent field

%Bacteria parameters
rotation_cnd = 0; %Should the bacteria be rotated?  0 for no rotation, 1 for randomised rotation for each diffusing particle
R = 0.25E-6;    %Radius of curvature in x.  Set to zero for a flat surface
L = (3E-6)-(2*R);   %Length of the cell up to the beginning of the cap (i.e. total cell length minus 2*Rcap)

%Restricted diffusion parameters
box_size = 0;%2.00e-007; %Restricted motion box edge length (m)
boundary_pass_threshold = 1;
mesh_wobble_cnd = 1;  %Should the mesh have a different location for each diffusing particle?  This 'wobble' simulates random cell rotation around the long axis

%Vacancy diffusion parameters
vac_diff_cnd = 0;
percentage_total_occupancy = 0.3;
R_OmpF = 1.7E-9;
R_OmpA = 1.3E-9;
R_BtuB = 2.3E-9;
rel_n_BtuB = 1;
rel_n_OmpF_trimer = 111;
rel_n_OmpA = 333;
local_range = 2*R_BtuB;

%Plotting parameters
plot_cnd = 0;% to suppress plotting, 1 to display a plot at the end


%% Recording the parameters
if vac_diff_cnd == 1 && box_size ~= 0
    question_response = questdlg('Can''t have restricted and vacancy diffuson.  Choose one', 'Mode choice', 'Restricted', 'Vacancy', 'Restricted');
    
    if strcmpi(question_response, 'Restricted')
        vac_diff_cnd = 0;
    else
        box_size = 0;
    end
end

try
    if exist(strcat([filename, '_Text output.txt'])) == 2
        delete(strcat([filename, '_Text output.txt']));
    end
    diary(strcat([filename, '_Text output.txt']));
    
end

%General parameters
disp(strcat(['Filename: ', filename]));
disp(strcat(['Diffusion coefficient (m^2): ', num2str(D)]));
disp(strcat(['Number of particles: ', num2str(n)]));
disp(strcat(['Total time (s): ', num2str(total_time_s)]));
disp(strcat(['Time increment (s): ', num2str(dt_s)]));

%Cell curvature parameters
if R ~= 0
    disp('Diffusion mapped to bacterial surface');
    disp(strcat(['Bacterial radius (m): ', num2str(R)]));
    disp(strcat(['Bacerial length (m): ', num2str(L)]));
    disp(strcat(['TIRF field depth (m): ', num2str(field_depth)]));
else
    disp('Planar diffusion');
end

%Rotation parameters
if rotation_cnd == 1
    disp('Random rotation enabled');
else
    disp('Random rotation disabled');
end

%Restricted diffusion parameters
if box_size ~= 0
    disp('Restricted diffusion enabled');
    disp(strcat(['Box size: ', num2str(box_size)]));
    disp(strcat(['Boundary pass threshold (0-1): ', num2str(boundary_pass_threshold)]));
    if mesh_wobble_cnd == 1
        disp('Random mesh wobble enabled');
    else
        disp('Random mesh wobble disabled');
    end
else
    disp('Restricted diffusion disabled');
end

if vac_diff_cnd == 1
    disp('Vacancy diffusion enabled');
    disp(strcat(['Radius of BtuB (m): ', num2str(R_BtuB)]));
    disp(strcat(['Radius of OmpF monomer (m): ', num2str(R_OmpF)]));
    disp(strcat(['Radius of OmpA (m): ', num2str(R_OmpA)]));
    disp(strcat(['Relative number of BtuBs: ', num2str(rel_n_BtuB)]));
    disp(strcat(['Relative number of OmpF trimers: ', num2str(rel_n_OmpF_trimer)]));
    disp(strcat(['Relative number of OmpA monomers: ', num2str(rel_n_OmpA)]));
    disp(strcat(['Target percentage occupancy: ~', num2str(percentage_total_occupancy*100), '%']));
    disp(strcat(['Local range (m): ', num2str(local_range)]));
else
    disp('Vacancy diffusion disabled');
end

diary off

save(strcat([filename, '_Settings']));
disp(' ');