clear all

% try
    %Initialising the random number generator
    reset(RandStream.getGlobalStream,sum(100*clock))

    %% Setting parameters
    filename_return = inputdlg('Enter filename for output');
    filename = filename_return{1};
    load(strcat([filename, '_Settings']));
    
    %% Calling the core system
    progress = waitbar(0, strcat([filename,' (Estimating time)']));
    msd_sum_table = zeros(round(total_time_s/dt_s)+1,1);
    n_table = zeros(round(total_time_s/dt_s)+1,1);
    msd_average_table = zeros(round(total_time_s/dt_s)+1,1);
    M_table = zeros(round(total_time_s/dt_s)+1,1);
    
    if vac_diff_cnd == 1
        [~, ~, x_max, y_max] = mcdRandomStart(R, field_depth, L);
        [membrane_table] = mcdPopulateMembrane(x_max*2, y_max*2, percentage_total_occupancy, R_OmpF, R_OmpA, R_BtuB, rel_n_OmpF_trimer, rel_n_OmpA, rel_n_BtuB);
    else
        membrane_table = [];
    end
    
    if plot_cnd == 1
        mcdMeshBug(L*1E6,R*1E6,20)
    end
    
    tic
    for i = 1:n
        if i ~= 1 %This waitbar displays the progress through the current iteration
            time_left = ((n-i)/i)*toc;
            time_format = 'secs';
            if time_left > 120
                time_left = time_left/60;
                time_format = 'mins';
            end
            
            try
                waitbar(i/n, progress, strcat([filename,' (~', num2str(ceil(time_left)), ' ', time_format, ' remain)']))
            catch
                progress = waitbar(0, strcat([filename,' (Estimating time)']));
            end
        end
        
        prev_n_table = n_table;
            
        [output_table, n_table] = mcdDiffusionCore(box_size, D, total_time_s, dt_s, R, L, field_depth, intensity0, d, mesh_wobble_cnd, rotation_cnd, plot_cnd, boundary_pass_threshold, n_table, vac_diff_cnd, membrane_table, R_BtuB, R_OmpA, R_OmpF, local_range);
        [msd_sum_table, msd_average_table, M_table] = mcdCalculateMSD(output_table, msd_sum_table, msd_average_table, n_table, prev_n_table, M_table);
        
        if i/250 == ceil(i/250)
            mcdStoreMonteCarloData(filename, i, dt_s, total_time_s, msd_average_table, n_table, M_table, 1);
        end
    end
    
    try
        close(progress)
    end
    
    mcdStoreMonteCarloData(filename, 1, dt_s, total_time_s, msd_average_table, n_table, M_table, 0);
    
    disp(' ');
    
% catch
%     errordlg(lasterr)
% end