function mtAnalyseTrackedParticles(filename, tether_length, drift_cnd)

kB = 1.38E-23;
temp = 293;

dot_loc = strfind(filename, '.');
root_filename = filename(1:dot_loc(length(dot_loc))-1);
ext = filename(dot_loc(length(dot_loc))+1:length(filename));

load(strcat(root_filename, '_Parameters.mat'));

if nargin > 2
    if drift_cnd == 1
        mtDriftCorrect(strcat([root_filename, '_Locations']), 'xls');
        tracked_table = xlsread(strcat([root_filename, '_Locations_drift corrected.xls']));
    else
        tracked_table = xlsread(strcat([root_filename, '_Locations.xls']));
    end
    
else
    tracked_table = xlsread(strcat([root_filename, '_Locations.xls']));
end

%If tracked_table is smaller (or equal to) one column the function exits
%with an error message, as an insufficient number of particles (i.e. none)
%have been detected
if size(tracked_table,2)<=1
    disp '**Insufficient number of particles detected**'
    return
end

analysed_data{1,2} = 'y position (px)';
analysed_data{1,3} = 'x position (px)';
analysed_data{1,4} = 'Mean residual';
analysed_data{1,5} = 'y displacement (px)';
analysed_data{1,6} = 'x displacement (px)';

if isa(pixel_distance, 'double')
    analysed_data{1,7} = 'y displacement (nm)';
    analysed_data{1,8} = 'x displacement (nm)';
    
    if isa(tether_length, 'double')
        analysed_data{1,9} = 'y force (pN)';
        analysed_data{1,10} = 'x force (pN)';
        
    end
end

for i = 1:(size(tracked_table,2)-1)/3
    analysed_data{i+1,1} = strcat(['Particle ', num2str(i)]);
    
    analysed_data{i+1,2} = nanmean(tracked_table(:,3*i-1));
    analysed_data{i+1,3} = nanmean(tracked_table(:,3*i));
    analysed_data{i+1,4} = nanmean(tracked_table(:,3*i+1));
    
    analysed_data{i+1,5} = sqrt((nanmean(tracked_table(:,3*i-1)...
        .^2))-((nanmean(tracked_table(:,3*i-1)))^2));
    
    analysed_data{i+1,6} = sqrt((nanmean(tracked_table(:,3*i)...
        .^2))-((nanmean(tracked_table(:,3*i)))^2));
    
    if isa(pixel_distance, 'double')
        analysed_data{i+1,7} = sqrt((nanmean(tracked_table(:,3*i-1)...
            .^2))-((nanmean(tracked_table(:,3*i-1)))^2))*pixel_distance;
        
        analysed_data{i+1,8} = sqrt((nanmean(tracked_table(:,3*i)...
            .^2))-((nanmean(tracked_table(:,3*i)))^2))*pixel_distance;
        
        if isa(tether_length, 'double')
            analysed_data{i+1,9} = ((kB*temp*tether_length*1E-9)/((analysed_data{i+1,7}*1E-9)^2))*(1E12);
            analysed_data{i+1,10} = ((kB*temp*tether_length*1E-9)/((analysed_data{i+1,8}*1E-9)^2))*(1E12);
            
        end
        
    end
end

if exist(strcat(root_filename, '_Analysis.xls')) == 2
    delete(strcat(root_filename, '_Analysis.xls'))
end

xlswrite(strcat([root_filename, '_Analysis.xls']), analysed_data);