function [peak_table] = mtImRegisterFit(peak_table, raw_data, R, n)

mask_R = ceil(max(peak_table(:,4))*2);

%This loop repeats for all the detected particles in "peak_table"
for i = 1:n     %It repeats for all the detected particles in 'peak_table)
    R = peak_table(i,4)+5; %Adding 5px extra to each edge of ROI
    
    %Setting the current raw image row and column (in pixels) for the
    %current particle
    row = ceil(peak_table(i,2))+mask_R;   %Peak y-midpoint
    col = ceil(peak_table(i,3))+mask_R;  %Peak x-midpoint
    
    %Sets the region of interest around the detected particle to the array
    %"roi", which is a section taken from the raw data image.  The size of
    %this region is determined by the user-defined (expected) particle
    %radius
    roi = raw_data(row-R:row+R,col-R:col+R);
    roi = double(roi-min(min(roi)))./255;
    roi = roi.*(1/max(max(roi)));
    roi_90 = imrotate(roi,90);
    roi_180 = imrotate(roi, 180);
    roi_270 = imrotate(roi, 270);
    
    optimizer = registration.optimizer.RegularStepGradientDescent;
    metric = registration.metric.MeanSquares;
    
    %imregister2 is a modified version of imregister, which outputs the
    %transformation required to align the input images
    [roi_out_180 transform_out_180] = imregister2(roi, roi_180, 'translation', optimizer, metric);
    [roi_out_90 transform_out_90] = imregister2(roi_90, roi_270, 'translation', optimizer, metric);
    
    %Updating "peak_table" with the best fit values of x and y from the
    %minimisation and correcting them for their location in the entire
    %image (they are output initially relative only to the region of
    %interest)
    dx = mean([transform_out_180.tdata.T(3,2)*0.5,transform_out_90.tdata.T(3,1)*0.5]);   %Corrected origin - x
    dy = mean([transform_out_180.tdata.T(3,1)*0.5,-transform_out_90.tdata.T(3,2)*0.5]);   %Corrected origin - y
    peak_table(i,2) = ceil(peak_table(i,2))- dx;
    peak_table(i,3) = ceil(peak_table(i,3))- dy;
    peak_table(i,5) = 1; %Residual from fminsearch, set to 1 here
        
end