%LINEDRAW.M

%This function generates a single image based on the measured particle
%locations.  The image shows a white line representing the path for each
%particle in "tracked_table".  Straight lines are drawn between the
%measured locations for each particle at each frame.  This function is
%similar in operation to "makemovie.m".

%INPUTS:
%"filename" is the root filename of the series of images to be analysed.

function mtLineDraw(filename)

dot_loc = strfind(filename, '.');
root_filename = filename(1:dot_loc(length(dot_loc))-1);
ext = filename(dot_loc(length(dot_loc))+1:length(filename));

%% ADD SOMETHING TO CHECK IF IT'S A VIDEO OR IMAGE
if exist(filename) == 0
    file_not_found_warn = warndlg(strcat(['File "', filename, '" not found']));
    uiwait(file_not_found_warn);
    return
end

video_object = VideoReader(filename);
data = read(video_object);

tracked_table = xlsread(strcat([root_filename, '_Locations.xls']));

%Loading the first image.
base_image = rgb2gray(data(:,:,:,1));

%Calculating the size of "tracked_table", so it can be used to determine
%the number of particles and the number of frames to be used
tracked_table_size = size(tracked_table);

%This set of loops goes through each frame up to the current frame and
%traces the path of each particle.
for current_frame = 1:tracked_table_size(1)
    %The second loop cycles through all the particles in
    %"tracked_table"
    for current_particle = 1:((tracked_table_size(2)-1)/3)
        %For each particle at each frame, a line between the previous
        %location and the current location is saved to "linetable".
        %There are 100 points in each line between two adjacent points.
        %Column 1 is the x-location and column 2 is the y-location
        try
            linetable(1:100,1) = linspace((tracked_table((current_frame)...
                ,(current_particle*3)-1)),(tracked_table((current_frame+1)...
                ,(current_particle*3)-1)),100);
            
            linetable(1:100,2) = linspace((tracked_table((current_frame)...
                ,(current_particle*3))),(tracked_table((current_frame...
                +1),(current_particle*3))),100);
            
            %All the points in "linetable" for the current particle and
            %step are superimposed onto the base image as having
            %maximum intensity (255).
            for i = 1:100
                base_image(round(linetable(i,1)),round(linetable(i,2)))...
                    = 255;
                
            end
        end
    end
end

try
    imshow(base_image);
catch
    image(base_image);
end

%This puts the particle number on an image next to that particular
%particle.  This is useful for comparing the same particles in
%different videos.
for current_particle = 1:((tracked_table_size(2)-1)/3)
    assigned_number_cnd = 0;
    current_row = 1;
    
    
    while assigned_number_cnd == 0
        
        if isnan(tracked_table(current_row,(current_particle*3))) == 0
            text((tracked_table(current_row,(current_particle*3)))-10,...
                (tracked_table(current_row,(current_particle*3)-1))-10,...
                num2str(current_particle), 'Color', 'w', 'FontSize', 6);
            assigned_number_cnd = 1;
            
        else
            
            current_row = current_row + 1;
            
        end
    end
    
end

try
    print('-dtiff', '-r200', strcat([root_filename, '_Numbered_line.png']));
end

pause(2)
close(gcf)