%LOADPARAMETERS.M

%This function loads parameters for use in the particle detection and
%tracking systems.  If an existing parameter file
%("tracking_parameters.mat") exists the parameters from that are loaded,
%but if not, default values are used.

%OUTPUTS
%"filename" is the root filename of the series of images to be analysed

%"numfiles" is the number of image files to be analysed

%"ext" is the file-type extension for the images being analysed.  It
%doesn't include the "." before the extension

%"filenumber" is used by particle detect to specify the image in the set to
%be analysed

%"R" is the user-defined particle radius

%"top_thres_multiplier" is used to define the cutoff above which pixel
%intensities will be taken to relate to particles

%"drift_threshold" determines the amount a particle centre can drift
%between adjacent frames of a video

%"disappear_threshold" is the number of frames a particle can go undetected
%while still being linked to a particle in previous frames

%"pixel_distance" is the real distance per pixel for the images.  This
%needs to come from calibration of the microscope and camera.


function [R top_thres_multiplier drift_threshold disappear_threshold ...
    pixel_distance] = mtLoadParameters(root_filename)

%If there are no existing parameters, these values are used for the
%options settings.  They need to be specified at the beginning else
%MATLAB may display an error message about not all arguments being
%assigned during call.

R = '20'; %Radius of the particles in pixels
top_thres_multiplier = '0.7'; %Formerly used for final identification
%of peaks (multiplier * standard deviation) + average.  Now we just use
%the basic thresholding
drift_threshold = '5';	%Distance a particle can move between images
disappear_threshold = '5'; %Number of frames a particle can disappear
%for, while still being recognised
pixel_distance = '108'; %Real distance per pixel in the images (nm/px)

%Checking to see if tracking_parameters exists.  This is set to "0" if not,
%and "2" if it does
tracking_parameters_exist = exist(strcat([root_filename, '_Parameters.mat']));

%If a previous tracking parameters file exists this loads the settings from
%the file to use as defaults in the dialog options.  Parameters need to be
%strings to use as default values for the options.
if tracking_parameters_exist == 2
    load(strcat([root_filename, '_Parameters.mat']));
    
end