%MAKEMOVIE.M

%This function takes the detected particle locations in "tracked_table" and
%generates a video file of the particle motions.  Each particle path is
%shown as a line.  This is similar in operation to
%"linedraw.m".

%INPUTS
%"filename" is the root filename of the series of images to be analysed.
%This is needed for loading images to be converted to a movie

function mtMakeMovie(filename)

dot_loc = strfind(filename, '.');
root_filename = filename(1:dot_loc(length(dot_loc))-1);
ext = filename(dot_loc(length(dot_loc))+1:length(filename));

%% ADD SOMETHING TO CHECK IF IT'S A VIDEO OR IMAGE
if exist(filename) == 0
    file_not_found_warn = warndlg(strcat(['File "', filename, '" not found']));
    uiwait(file_not_found_warn);
    return
end

video_object = VideoReader(filename);
data = read(video_object);
tracked_table = xlsread(strcat([root_filename, '_Locations.xls']));

%Calculating the size of "tracked_table", so it can be used to determine
%the number of particles and the number of frames to go into the video
tracked_table_size = size(tracked_table);

%For many images, generating the video can take quite a while, so a
%progress bar is displayed.  Here, this is initialised.
progress = waitbar(0, 'Generating video...');

figure
hold on

%For each frame (row in "tracked_table") this loop completes a single
%iteration, generating a new frame of the video
for frame_i = 1:(tracked_table_size(1)-1)
    %Keeping the progress bar updated with the current frame being
    %processed
    waitbar(frame_i/(tracked_table_size(1)-1))
    
    %imshow(b - rgb2gray(data(:,:,:,frame_i)));
    imshow(rgb2gray(data(:,:,:,frame_i)));
    hold on
    
    for current_particle = 1:((tracked_table_size(2)-1)/2)
        %base_image(ceil(tracked_table(frame_i, current_particle*2)), ceil(tracked_table(frame_i, current_particle*2+1))) = 255;
        dot = plot(tracked_table(frame_i, current_particle*2+1),tracked_table(frame_i, current_particle*2), 'r');
    end
    
    %Once all frame steps and particles up to the current frame have been
    %superimposed onto the base image, the image is saved to the 3D array,
    %"M" at the current frame number
    temp_im = getframe(gcf);
    M(frame_i) = im2frame(temp_im.cdata,gray(256));
    delete(dot)
    
    %The base image is cleared for the next image
    clear base_image
    
end

%Updating the progress bar to say "Saving video..."
waitbar(1, progress, 'Saving video...');

%Once all frames in a set have been rendered and saved to "M", "M" is
%converted to an uncompressed movie file
movie2avi(M, strcat(root_filename, '_Paths.avi'), 'compression', 'None')

%Closing the progress bar
close(progress)

disp(' ');