function [R] = mtSelectParticles(filename, R)

if nargin == 1
    R = 10; %Starting bead radius; this will be updated when beads are selected
end

dot_loc = strfind(filename, '.');
root_filename = filename(1:dot_loc(length(dot_loc))-1);
ext = filename(dot_loc(length(dot_loc))+1:length(filename));

%% ADD SOMETHING TO CHECK IF IT'S A VIDEO OR IMAGE
if exist(filename) == 0
    file_not_found_warn = warndlg(strcat(['File "', filename, '" not found']));
    uiwait(file_not_found_warn);
    return
end

video_object = VideoReader(filename);
n_frames = video_object.NumberOfFrames;
data = read(video_object,1);
test_image = rgb2gray(data(:,:,:,1));

%% Displaying the calibration image and setting it full screen
screen_dimensions = get(0, 'ScreenSize');
curr_fig = figure();
imshow(test_image);
daspect([1 1 1])
set(curr_fig, 'Position', screen_dimensions+[100 50 -200 -150]);
curr_axes = gca;

%% Initialising some variables
bead_i = 1;
BG_roi = [];
BG_pos = [];
bead_roi = 0;
bead_pos = [];
set_BG_cnd = 0;
set_bead_cnd = 0;
BG_rect = [];
bead_centre = [];
bead_radius = [];
BG_mean_int = 0;

%% Setting the UI elements
uicontrol('Style', 'pushbutton', 'String', 'Select another', 'Units', ...
    'Normalized', 'Position', [0.915 0.22 0.07 0.04], 'Callback', ...
    @selectBead);
    function selectBead(~, ~)
        %"bead_roi" needs to be initialised before entering the uicontrol
        %function, this removes that initial initialisation since it's in
        %the wrong format.
        if bead_i == 1
            clear bead_roi
            
        else
            pos = bead_roi(size(bead_roi,2)).getPosition;
            R = pos(3)/2;
            
        end
        
        bead_centre(bead_i,1:2) = ginput(1);
        bead_roi(bead_i) = imellipse(curr_axes, [bead_centre(bead_i,1)-R bead_centre(bead_i,2)-R 2*R 2*R]);
        bead_roi(bead_i).setFixedAspectRatioMode(1);
        bead_pos(bead_i, 1:4) = bead_roi(bead_i).getPosition;
        
        set_bead_cnd = 1;
        bead_i = bead_i + 1;
        
    end

uicontrol('Style', 'pushbutton', 'String', 'Save', 'Units', ...
    'Normalized', 'Position', [0.915 0.12 0.07 0.04], 'Callback', ...
    @saveData);
    function saveData(~, ~)
        for i = 1:bead_i-1
            bead_pos(i,1:4) = bead_roi(i).getPosition;
            
            peak_table(i,1) = i; %Peak number
            peak_table(i,2) = ceil(bead_pos(i,2)+bead_pos(i,3)/2); %y-pos
            peak_table(i,3) = ceil(bead_pos(i,1)+bead_pos(i,3)/2); %x-pos
            R = ceil(bead_pos(i,3)/2); %radius
            peak_table(i,4) = R;
            
        end
        
        bead_centre(:,1:2) = [bead_pos(:,1)+bead_pos(:,3)/2,bead_pos(:,2)+bead_pos(:,4)/2];
        bead_radius(1:bead_i-1) = mean(bead_pos(:,3:4),2)/2;
        
        BG_mean_int = mean(mean(test_image));
        
        for i = 1:size(test_image,1)
            for j = 1:size(test_image,2)
                for k = 1:bead_i-1
                    if sqrt((i-bead_centre(k, 2))^2+(j-bead_centre(k, 1))^2) < bead_radius(k)
                        
                        test_image(i,j) = BG_mean_int;
                        
                    end
                end
            end
        end

        imwrite(test_image, strcat([root_filename, '_Background.png']));
        
        if exist(strcat(root_filename, '_Start Positions.xls')) == 2
            delete(strcat(root_filename, '_Start Positions.xls'))
        end
        
        xlswrite(strcat([root_filename, '_Start Positions.xls']), peak_table)
        close(curr_fig)
    end

selectBead

waitfor(curr_fig);

end
