%TRACKERDETECTIONSETTINGS.M

%This function asks the user to specify the parameters for the particle
%tracking system.  The default values are either previously used values or
%defaults written into "loadparameters.m".  These parameters are then
%returned to the particle tracker.


function mtTrackerDetectionSettings(filename)

dot_loc = strfind(filename(1,:), '.');
root_filename = filename(1, 1:dot_loc(length(dot_loc))-1);
ext = filename(1,dot_loc(length(dot_loc))+1:length(filename(1,:)));

%% ADD SOMETHING TO CHECK IF IT'S A VIDEO OR IMAGE
if exist(filename(1,:)) == 0
    file_not_found_warn = warndlg(strcat(['File "', filename(1,:), '" not found']));
    uiwait(file_not_found_warn);
    return
end

video_object = VideoReader(filename(1,:));
n_frames = video_object.NumberOfFrames;

%Loading previously stored parameters if they exist in a previous
%configuration file.  If there is no previous file, defaults are loaded.  A
%couple of parameters are loaded, which are unrequired (used by particle
%detect only), these can be ignored.
[R top_thres_multiplier drift_threshold disappear_threshold ...
    pixel_distance] = mtLoadParameters(root_filename);

%The settings for the dialog.  Here, the titles of the parameters to be
%asked for, the title of the prompt window, the number of lines per entry
%field and the default values are set.
detection_settings_prompt = {'Particle radius (pixels)', 'Upper threshold',...
    'Drift (pixels)', 'Disappear threshold (frames)', 'Pixel distance (nm/px)'};
detection_settings_title = 'Enter detection settings';
detection_settings_lines = 1;
detection_settings_defaults = {num2str(R), num2str(top_thres_multiplier), ...
    num2str(drift_threshold), num2str(disappear_threshold), num2str(pixel_distance)};

%Calling the input dialog function using the previously assigned settings
detection_settings = inputdlg(detection_settings_prompt, ...
    detection_settings_title, detection_settings_lines, ...
    detection_settings_defaults);

%The user-input values in the input dialog are saved to the cell-array
%"detection_settings" in the order they were in the dialog.  These are
%accessed and assigned to the relevant variables.  The contents of
%"detection_settings" are all strings, but some need to be in the
%double-number format, hence the use of "str2double".
R = str2double(detection_settings{1});
top_thres_multiplier = str2double(detection_settings{2});
drift_threshold = str2double(detection_settings{3});
disappear_threshold = str2double(detection_settings{4});
pixel_distance = str2double(detection_settings{5});

if size(filename,1) > 1
    for i = 1:size(filename, 1)
        dot_loc = strfind(filename(i,:), '.');
        root_filename = filename(i, 1:dot_loc(length(dot_loc))-1);
        save(strcat([root_filename, '_Parameters.mat']),'root_filename', 'n_frames', 'ext', ...
            'R', 'top_thres_multiplier', 'drift_threshold', 'disappear_threshold', 'pixel_distance');
    end
    
else
    save(strcat([root_filename, '_Parameters.mat']),'root_filename', 'n_frames', 'ext', ...
        'R', 'top_thres_multiplier', 'drift_threshold', 'disappear_threshold', 'pixel_distance');
    
end