%MULTITRACKER.M

%This is the main script, which runs the "Multitracker" MATLAB particle
%detection and tracking system.  It's main purpose is to load some
%parameters (more important parameters, such as filename and number of
%files are requested of the user in prompts when the system runs) and
%determine which mode should be executed (particle detection, tracking or
%one of the analysis routines)

function multiTracker(file_path)
filename = {''};

%Setting some less important thresholds and parameters
warning off %Telling MATLAB not to display warnings

MaxFunEvals = 2000000; %A parameter required for "gauss_cnd = 2 and 3",
%which determines the maximum number of evaluations the minimsation
%function will perform.  Decreasing this speeds up code execution, but
%decreases particle detection accuracy.

TolFun = 1e-6;

TolX = 1e-6;

allow_miss_percentage = 75; %The percentage of frames a particle may be
%absent from before it is discarded.  This can be increased for videos
%where particles rapidly appear and disappear

movie_cnd = 0; %Determines if the tracked particles are displayed in a
%video after particle tracking has executed

mtLineDraw_cnd = 1; %Determines if the tracked particles are displayed in an
%image after particle tracking has executed

%The main part of the script
%Calling the function, which will ask the user to determine which mode will
%be run.  The different modes are identified by a number
[mode] = mtModeChoice;

if exist('file_path') ~= 0
    temp_slash = findstr(file_path, '\');
    filename = {file_path(temp_slash(length(temp_slash))+1:length...
        (file_path))};
    curr_dir = pwd;
    cd(file_path(1:temp_slash(length(temp_slash))));
    
end

if mode == 1 %New multiple tracking system
    if exist('Video_list.txt', 'file') ~= 0
        selection = questdlg('Track particles in all videos named in "Video_list.txt"?', 'Mode selection', 'Yes', 'No', 'Yes');
        
        if strcmpi(selection, 'Yes')
            [video_names, ~, tether_length] = textread('Video_list.txt',...
                '%s %f %f', 'whitespace', '\t');
            
            for i = 1:length(video_names) %Checking all the necessary files exist first
                mtCheckFilesFirst(char(video_names(i)))
            end
            
            for i = 1:length(video_names)
                mtParticleTracking(char(video_names(i)), tether_length(i), MaxFunEvals, TolFun, TolX, allow_miss_percentage, movie_cnd, mtLineDraw_cnd)
                
            end
            
        elseif strcmpi(selection, 'No')
            filename = inputdlg('Enter video filename (with extension)',...
                'Filename selection', 1, filename);
            mtCheckFilesFirst(char(filename))
            tether_length_result = inputdlg('Enter tether length (nm)');
            tether_length = str2double(tether_length_result(1));
            mtParticleTracking(char(filename), tether_length, MaxFunEvals, TolFun, TolX, allow_miss_percentage, movie_cnd, mtLineDraw_cnd)
            
        end
        
    else
        filename = inputdlg('Enter video filename (with extension)', ...
            'Filename selection', 1, filename);
        mtCheckFilesFirst(char(filename))
        tether_length_result = inputdlg('Enter tether length (nm)');
        tether_length = str2double(tether_length_result(1));
        mtParticleTracking(char(filename), tether_length, MaxFunEvals, TolFun, TolX, allow_miss_percentage, movie_cnd, mtLineDraw_cnd)
        
    end
    
elseif mode == 2 %Create a background image
    %If there is a list of all the video files to be analysed the user is
    %asked if they want to create a background image for all.  If they
    %don't, or if no video list exists, they are asked to enter the
    %filename.  Whatever the decision, the function "createBackgroundImage"
    %is run with the chosen filename(s).
    if exist('Video_list.txt', 'file') ~= 0
        selection = questdlg('Select particles in all videos named in "Video_list.txt"?', 'Mode selection', 'Yes', 'No', 'Yes');
        
        if strcmpi(selection, 'Yes')
            [video_names, ~, ~] = textread('Video_list.txt',...
                '%s %f %f', 'whitespace', '\t');
            
            select_R = mtSelectParticles(char(video_names(1)));
            for i = 2:length(video_names)
                select_R = mtSelectParticles(char(video_names(i)), select_R);
            end
            
        elseif strcmpi(selection, 'No')
            filename = inputdlg('Enter video filename (with extension)',...
                'Filename selection', 1, filename);
            mtSelectParticles(char(filename));
            
        end
        
    else
        filename = inputdlg('Enter video filename (with extension)', ...
            'Filename selection', 1, filename);
        mtSelectParticles(char(filename));
        
    end
    
elseif mode == 3
    %If there is a list of all the video files to be analysed the user is
    %asked if they want to create a variable file for all.  If they
    %don't, or if no video list exists, they are asked to enter the
    %filename.  Whatever the decision, the function "createSettingsFile"
    %is run with the chosen filename(s).
    if exist('Video_list.txt', 'file') ~= 0
        selection = questdlg('Create settings file for all videos named in "Video_list.txt"?', 'Mode selection', 'Yes', 'No', 'Yes');
        
        if strcmpi(selection, 'Yes')
            [video_names, ~, ~] = textread('Video_list.txt',...
                '%s %f %f', 'whitespace', '\t');
            
            identical_settings_cnd = questdlg('Use the same settings for all files?', 'Mode selection', 'Yes', 'No', 'Yes');
            
            if strcmpi(identical_settings_cnd, 'Yes')
                mtTrackerDetectionSettings(char(video_names));
                
            else
                for i = 1:length(video_names)
                    mtTrackerDetectionSettings(char(video_names(i)));
                end
            end
            
        elseif strcmpi(selection, 'No')
            filename = inputdlg('Enter video filename (with extension)',...
                'Filename selection', 1, filename);
            mtTrackerDetectionSettings(char(filename));
            
        end
        
    else
        filename = inputdlg('Enter video filename (with extension)', ...
            'Filename selection', 1, filename);
        mtTrackerDetectionSettings(char(filename));
        
    end
    
elseif mode == 4; %Draws a line on the first image that
    %relates to the path of the particles in an image
    
    if exist('Video_list.txt', 'file') ~= 0
        selection = questdlg('Show tracked paths for all videos named in "Video_list.txt"?', 'Mode selection', 'Yes', 'No', 'Yes');
        
        if strcmpi(selection, 'Yes')
            [video_names, ~, ~] = textread('Video_list.txt',...
                '%s %f %f', 'whitespace', '\t');
            
            for i = 1:length(video_names)
                mtLineDraw(char(video_names(i)));
            end
            
        elseif strcmpi(selection, 'No')
            filename = inputdlg('Enter video filename (with extension)',...
                'Filename selection', 1, filename);
            mtLineDraw(char(filename));
        end
        
    else
        filename = inputdlg('Enter video filename (with extension)', ...
            'Filename selection', 1, filename);
        mtLineDraw(char(filename));
    end
    
elseif mode == 5
    
    if exist('Video_list.txt', 'file') ~= 0
        selection = questdlg('Show tracked paths for all videos named in "Video_list.txt"?', 'Mode selection', 'Yes', 'No', 'Yes');
        
        if strcmpi(selection, 'Yes')
            [video_names, ~, ~] = textread('Video_list.txt',...
                '%s %f %f', 'whitespace', '\t');
            
            for i = 1:length(video_names)
                mtMakeMovie(char(video_names(i)));
            end
            
        elseif strcmpi(selection, 'No')
            filename = inputdlg('Enter video filename (with extension)',...
                'Filename selection', 1, filename);
            mtMakeMovie(char(filename));
        end
        
    else
        filename = inputdlg('Enter video filename (with extension)', ...
            'Filename selection', 1, filename);
        mtMakeMovie(char(filename));
    end
    
elseif mode == 6
    
    if exist('Video_list.txt', 'file') ~= 0
        selection = questdlg('Analyse data for all videos named in "Video_list.txt"?', 'Mode selection', 'Yes', 'No', 'Yes');
        
        if strcmpi(selection, 'Yes')
            [video_names, ~, tether_length] = textread('Video_list.txt',...
                '%s %f %f', 'whitespace', '\t');
            
            drift_cnd = questdlg('Correct for drift?', 'Mode selection', 'Yes', 'No', 'Yes');
            for i = 1:length(video_names)
                if strcmpi(drift_cnd, 'Yes')
                    mtAnalyseTrackedParticles(char(video_names(i)),tether_length(i),1);
                else
                    mtAnalyseTrackedParticles(char(video_names(i)),tether_length(i),0);
                end
            end
            
        elseif strcmpi(selection, 'No')
            filename = inputdlg('Enter video filename (with extension)',...
                'Filename selection', 1, filename);
            drift_cnd = questdlg('Correct for drift?', 'Mode selection', 'Yes', 'No', 'Yes');
            tether_length = inputdlg('Enter tether length (nm)',...
                'Enter settings', 1);
            if strcmpi(drift_cnd, 'Yes')
                mtAnalyseTrackedParticles(char(filename),str2double(tether_length{1}), 1);
            else
                mtAnalyseTrackedParticles(char(filename),str2double(tether_length{1}), 0);
            end
        end
        
    else
        filename = inputdlg('Enter video filename (with extension)', ...
            'Filename selection', 1, filename);
        drift_cnd = questdlg('Correct for drift?', 'Mode selection', 'Yes', 'No', 'Yes');
        if strcmpi(drift_cnd, 'Yes')
            mtAnalyseTrackedParticles(char(filename),1);
        else
            mtAnalyseTrackedParticles(char(filename),0);
        end
    end
    
elseif mode == 7
    if exist('Video_list.txt', 'file') == 0
        warndlg('"Video_list.txt" required');
        
    else
        output_filename = inputdlg('Enter output filename');
        output_filename = char(output_filename);
        
        mtSequenceAnalysis(output_filename);
        
    end
    
end

if exist('file_path') ~= 0
    cd(curr_dir);
    
end

disp(' ');