function numberImageStack(file_path)

%% Getting the file names
if exist('file_path') == 0
    input_return = inputdlg('Enter filename (without extension)');
    
    %If the cancel button was pressed the system exits
    if size(input_return,1) == 0
        return
    end
    
    root_f_name = input_return{1};
    
    %If the file is dragged onto the .exe the following gets the filename
    %and path.
else
    temp_slash = findstr(file_path, '\');
    root_f_name = file_path(temp_slash(length(temp_slash))+1:length...
        (file_path)-8);
    start_dir = pwd;
    cd(file_path(1:temp_slash(length(temp_slash))));
    
end
%% Initialising some values
screen_dimensions = get(0, 'ScreenSize');
f_list = dir;


%% Importing the images specified by the root filename
%Calculating the number of images in the current directory starting with
%the specified root filename.  This value will be used to initialise the
%im_stack variable.  The first image is saved to the first layer of the
%stack to give the variable the correct x and y dimensions.
import_num = 0;
for i = 1:length(f_list)
    f_name = f_list(i).name;
    if length(f_name) > length(root_f_name)
        if strcmpi(f_name(1:length(root_f_name)), root_f_name) ...
                && size(strfind('tif,jpg,bmp,png', f_name(length(f_name...
                )-2:length(f_name))),1) > 0 ...
                && length(f_name) == length(root_f_name)+8
            
            import_num = import_num + 1;
            
            if import_num == 1
                if size(imread(f_name),3) == 1
                    im_stack(:,:,1) = imread(f_name);
                    
                else
                    im_stack(:,:,1) = rgb2gray(imread(f_name));
                end
            end
        end
    end
end

%Initialising the rest of the stack layers
im_stack(:,:,2:import_num) = 0;

%Importing the images to each layer of "im_stack"
progress = waitbar(0, 'Loading images');
im_stack_i = 1;
for i = 1:length(f_list)
    waitbar(i/length(f_list));
    f_name = f_list(i).name;
    
    if length(f_name) > length(root_f_name)
        if strcmpi(f_name(1:length(root_f_name)), root_f_name) ...
                && size(strfind('tif,jpg,bmp,png', f_name(length(f_name...
                )-2:length(f_name))),1) > 0 ...
                && length(f_name) == length(root_f_name)+8
            
            if size(imread(f_name),3) == 1
                im_stack(:,:,im_stack_i) = imread(f_name);
                
            else
                im_stack(:,:,im_stack_i) = rgb2gray(imread(f_name));
                
            end
            
            im_stack_i = im_stack_i + 1;
        end
    end
    
end

close(progress);

%% Specifying the number locations
%Displaying the first image in the stack and resizing it to fill the screen
curr_fig = figure();
imshow(im_stack(:,:,1));
set(curr_fig, 'Position', screen_dimensions);

%Setting a button on the image, which is pressed once all numbers have been
%placed.  This tells the script to exit the number-placing loop and enter
%the phase where numbers are written to each image.
uicontrol('Style', 'pushbutton', 'String', 'Finished', 'Units', ...
    'Normalized', 'Position', [0.927 0.12 0.05 0.04], 'Callback', ...
    @tryOverlay);
    function tryOverlay(~, ~)
        adding_nums_cnd = 1;
        print('-dtiff', '-r200', strcat(['Numbered_', root_f_name, ...
            '.jpg']));
        close(gcf)
    end

%Initialising some variables
num_selected = 0;
adding_nums_cnd = 0;
x = [];
y = [];

%The following loop executes all the time "adding_nums_cnd" is set to "0".
%This variable is changed to "1" when the user presses the "Finished"
%button.
while adding_nums_cnd == 0
    %Once "Measure" has been selected the code will want to do a final
    %selection, which has already been called.  When the figure is closed,
    %this incomplete function would cause the code to fail.  This prevents
    %that.
    try
        if ishandle(curr_fig)
            [temp_x,temp_y] = getpts;
            for i = 1:length(temp_x)
                text(temp_x(i),temp_y(i), num2str(i+num_selected), ...
                    'Color', [1 0 0 ], 'FontWeight' ,'bold');
                
            end
            
            num_selected = num_selected + length(temp_x);
            x = [x;temp_x];
            y = [y;temp_y];
            
        else
            return
            
        end
    end
end

%% Placing the numbers on each image in "im_stack" and saving as a video
%Opening the video file for writing
video_object = VideoWriter(strcat(['Numbered_', root_f_name, '.avi']), ...
    'Uncompressed AVI');
open(video_object)

%Going through the images, writing the numbers at the same location and
%saving to the current video frame.
for i = 1:size(im_stack,3)
    figure();
    imshow(im_stack(:,:,i));
    for j = 1:length(x)
        text(x(j),y(j), num2str(j), 'Color', [1 0 0 ], 'FontWeight' ...
            ,'bold');
        
    end
    
    drawnow
    writeVideo(video_object, getframe(gca));
    close(gcf)
    
end

close(video_object)

if exist('file_path') == 1
    cd(start_dir);
    
end

end