function particleSizeDist(filename, R, R_added)
%Setting the number of data points and radial lines to measure
n_lines = 300;
n_points = 500;

%Loading files
dot_loc = strfind(filename, '.');
root_filename = filename(1:dot_loc(length(dot_loc))-1);
ext = filename(dot_loc(length(dot_loc))+1:length(filename));
try
    raw_data = rgb2gray(imread(filename));
catch
    raw_data = imread(filename);
end

%Manually selecting particle centres and saving to peak_table
[peak_table] = psdSelectParticles(root_filename, raw_data, R);
peak_table(:,4) = peak_table(:,4) + R_added;

%Taking radial intensity profiles from the particle centres and averaging.
%Averaged profiles are saved to mean_pro_data
mean_pro_data = psdMeasureRadialProfile(raw_data, peak_table, n_lines, ...
    n_points, root_filename);

%Taking the gradient of each average profile and fitting a Gaussian.  The
%bead edge is taken to be the maxima of the Gaussian (greatest gradient).
%When taking the curve gradient the second argument of the function
%gradient() should have been the increment as calculated using:
%(mean_pro_data(1,2)-mean_pro_data(1,1)).  Instead, MATLAB takes the
%increment to be 1.  This isn't a problem, but means y0 and A from the fit
%are out by a factor of 1/increment.
for i = 1:size(mean_pro_data,2)/2
    [xc, w, A, y0] = psdGaussFit([mean_pro_data(:,2*i-1),-gradient(...
        mean_pro_data(:,2*i))], root_filename, i);
    peak_table(i,5) = xc;
    peak_table(i,6) = w;
    peak_table(i,7) = A;
    peak_table(i,8) = y0;
end

%Saving the data to a file suffixed with "Positions"
try
    if exist(strcat(root_filename, '_Positions.xls')) == 2
        delete(strcat(root_filename, '_Positions.xls'))
    end
    xlswrite(strcat([root_filename, '_Positions.xls']), peak_table)
end